<?php

/**
 * Builds the output for the domain list in the DRD dashboard including
 * filters, operations and the list of domains with their details.
 *
 * @param type $sid
 * @return type
 */
function drd_domain($sid = 0) {
  if ($sid) {
    if ($sid == 'reset') {
      $_SESSION['drd']['filter']['domain']['sids'] = array();
    }
    else {
      $_SESSION['drd']['filter']['domain']['sids'] = array($sid);
    }
    drupal_goto('admin/config/system/drd/dashboard/domains');
  }
  if (!empty($_POST['domains']) && isset($_POST['operation'])) {
    drd_operation('domain', $_POST['domains'], $_POST['operation']);
  }
  $build['domain_filter_form'] = drupal_get_form('drd_domain_filter_form');
  $build['domain_list'] = drupal_get_form('drd_domain_list');

  return $build;
}

/**
 * Builds the domain list according to the current filter settings.
 *
 * @param type $form
 * @param type $form_state
 * @return string
 */
function drd_domain_list($form, &$form_state) {
  $header = array(
    'name'   => array('data' => t('Name'),      'field' => 'd.name', 'sort' => 'asc'),
    'url'    => array('data' => t('URL'),       'field' => 'd.url'),
    'usessl' => array('data' => t('SSL'),       'field' => 'd.usessl'),
    'status' => array('data' => t('Status'),    'field' => 'd.status'),
    'inst'   => array('data' => t('Installed'), 'field' => 'd.installed'),
    'aliases'=> array('data' => t('Aliases')),
  );

  $query = db_select('drd_domain', 'd');

  drd_domain_build_filter_query($query);

  $count_query = clone $query;
  $count_query->addExpression('COUNT(d.did)');

  $query = $query->extend('PagerDefault')->extend('TableSort');
  $query
    ->fields('d')
    ->limit(100)
    ->orderByHeader($header)
    ->setCountQuery($count_query);
  $result = $query->execute();

  if ($result->rowCount() > 0) {
    drd_operation_build_form($form, 'domain');
  }

  $destination = drupal_get_destination();

  $domains = array();
  foreach ($result as $d) {
    $warning = ($d->status_w) ? drd_icon('warning') : '';
    $error   = ($d->status_e) ? drd_icon('error') : '';
    $count = db_select('drd_domain_alias', 'a')->fields('a', array('aid'))->condition('a.did', $d->did)->countQuery()->execute()->FetchField() - 1;
    $extra = '<div class="drd-info element-hidden">&nbsp;</div>';
    $domains[$d->did] = array(
      '#attributes' => array(
        'id' => 'drd-domain-' . $d->did,
        'class' => array('drd-data'),
      ),
      'name'   => array(
        'data' => l($d->name, 'admin/config/system/drd/domain/' . $d->did . '/edit', array('query' => $destination)) . $extra,
        'class' => array('name'),
      ),
      'url'    => l($d->url, drd_url($d), array('attributes' => array('target' => '_blank'))),
      'usessl' => ($d->usessl) ? t('Yes') : t('No'),
      'status' => array(
        'data' => (($d->status) ? t('Active') : t('Disabled')) . $warning . $error,
        'class' => array('pointer'),
      ),
      'inst'   => ($d->installed) ? t('Yes') : t('No'),
      'aliases'=> $count,
    );
  }

  $form['domains'] = array(
    '#type' => 'tableselect',
    '#header' => $header,
    '#options' => $domains,
    '#empty' => t('No domains available.'),
  );
  $form['domain_list_pager'] = array('#theme' => 'pager');

  drupal_add_js(array('drd' => array('urlAjax' => url('admin/drd/ajax/domain/'))), 'setting');

  return $form;
}

/**
 * Builds the filter form for the domain list.
 *
 * @return type
 */
function drd_domain_filter_form() {
  return array();
}

/**
 * Builds the filter query for the domain list.
 *
 * @param type $query
 */
function drd_domain_build_filter_query(&$query) {
  if (!empty($_SESSION['drd']['filter']['domain']['sids'])) {
    $query->condition('d.sid', $_SESSION['drd']['filter']['domain']['sids']);
  }
}
