<?php

/**
 * Build the form to edit server properties.
 *
 * @param type $form
 * @param type $form_state
 * @param type $sid
 * @return type
 */
function drd_server_edit($form, &$form_state, $sid = 0) {
  if ($sid) {
    $server = (array)drd_server_load($sid);
  }
  else {
    $server = array(
      'sid' => 0,
      'name' => '',
      'url' => '',
      'usessl' => 0,
      'status' => 1,
      'weight' => 0,
      'aes_key' => '',
      'aes_cipher' => '',
      'aes_iv' => '',
      'aes_impl' => '',
      'drupalversion' => '',
      'svnenable' => 0,
      'svnusername' => '',
      'svnuserpass' => '',
      'svnforceexternal' => 1,
      'svnrevision' => 0,
    );
  }
  if (empty($server['aes_iv'])) {
    $aes_iv_org = variable_get("aes_encryption_iv", '');
    aes_make_iv(TRUE);
    $server['aes_iv'] = variable_get("aes_encryption_iv", '');
    variable_set("aes_encryption_iv", $aes_iv_org);
  }

  $form['#server'] = $server;

  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#default_value' => $server['name'],
    '#max_length' => 255,
  );
  $form['url'] = array(
    '#type' => 'textfield',
    '#title' => t('URL'),
    '#default_value' => $server['url'],
    '#max_length' => 255,
  );
  $form['usessl'] = array(
    '#type' => 'checkbox',
    '#title' => t('Use SSL'),
    '#default_value' => $server['usessl'],
  );
  $form['status'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enabled'),
    '#default_value' => $server['status'],
  );
  $form += aes_config();
  unset($form['aes']['aes_convert']);
  unset($form['aes']['view_method']);
  unset($form['aes']['aes_key_storage_method']);
  unset($form['aes']['aes_key_path']);
  unset($form['aes']['submit']);
  $form['aes']['aes_implementation']['#default_value'] = $server['aes_impl'];
  $form['aes']['aes_cipher']['#default_value'] = $server['aes_cipher'];
  $form['aes']['aes_iv'] = array(
    '#type' => 'textfield',
    '#title' => 'AES IV',
    '#default_value' => $server['aes_iv'],
    '#disabled' => TRUE,
  );

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}

/**
 * Validates the edited server properties before submitting them.
 *
 * @param type $form
 * @param type $form_state
 */
function drd_server_edit_validate($form, &$form_state) {
  if (!empty($form_state['values']['aes_key'])) {
    if ($form_state['values']['aes_key'] !== $form_state['values']['aes_key_c']) {
      form_set_error('aes_key', t("The encryption keys didn't match."));
    }
  }
}

/**
 * Submits the edited server properties and installs the server if required.
 *
 * @param type $form
 * @param type $form_state
 */
function drd_server_edit_submit($form, &$form_state) {
  $changed = FALSE;
  $values = $form_state['values'];
  $server = $form['#server'];
  $server['name'] = $values['name'];
  $server['url'] = $values['url'];
  $server['usessl'] = $values['usessl'];
  $server['status'] = $values['status'];
  $server['aes_impl'] = $values['aes_implementation'];
  $server['aes_cipher'] = $values['aes_cipher'];
  $server['aes_iv'] = $values['aes_iv'];
  if (!empty($form_state['values']['aes_key'])) {
    $changed = ($server['aes_key'] !== $values['aes_key']);
    $server['aes_key'] = $values['aes_key'];
  }
  if ($server['sid']) {
    db_update('drd_server')
      ->fields($server)
      ->condition('sid', $server['sid'])
      ->execute();
  }
  else {
    drupal_write_record('drd_server', $server);
    $changed = FALSE;
    $result = drd_install_drd_server('install server', 'server', $server['sid'], FALSE);
    if (!$result) {
      drupal_set_message('Server installation failed, please check manually.', 'error');
    }
    else if ($result == 'Either module DRD_SERVER or AES can not be enabled.') {
      drupal_set_message($result, 'error');
    }
    else {
      drupal_set_message($result);
      $query = drupal_get_destination();
      $query['goto'] = '1';
      $query['destination'] = 'admin/config/system/drd/dashboard';
      $link = l('here', 'admin/config/system/drd/server/' . $server['sid'] . '/pushaes', array('query' => $query));
      drupal_set_message('After that, click ' . $link . ' to push the AES keys to the server.');
    }
    drupal_goto('admin/config/system/drd/dashboard');
  }
  if ($changed) {
    drd_update_aes($server['sid']);
  }
}
