<?php

/**
 * Builds the output for the server list in the DRD dashboard including
 * filters, operations and the list of servers with their details.
 *
 * @return type
 */
function drd_server() {
  if (!empty($_POST['server']) && isset($_POST['operation'])) {
    drd_operation('server', $_POST['server'], $_POST['operation']);
  }
  $build['server_filter_form'] = drupal_get_form('drd_server_filter_form');
  $build['server_list'] = drupal_get_form('drd_server_list');

  return $build;
}

/**
 * Builds the server list according to the current filter settings.
 *
 * @param type $form
 * @param type $form_state
 * @return string
 */
function drd_server_list($form, &$form_state) {
  $header = array(
    'name'   => array('data' => t('Name'),   'field' => 's.name', 'sort' => 'asc'),
    'url'    => array('data' => t('URL'),    'field' => 's.url'),
    'usessl' => array('data' => t('SSL'),    'field' => 's.usessl'),
    'status' => array('data' => t('Status'), 'field' => 's.status'),
    'drupal' => array('data' => t('Drupal'), 'field' => 's.drupalversion'),
    'svn'    => array('data' => t('SVN'),    'field' => 's.svnenable'),
    'domains'=> array('data' => t('Domains')),
  );

  $query = db_select('drd_server', 's');

  drd_server_build_filter_query($query);

  $count_query = clone $query;
  $count_query->addExpression('COUNT(s.sid)');

  $query = $query->extend('PagerDefault')->extend('TableSort');
  $query
    ->fields('s')
    ->limit(25)
    ->orderByHeader($header)
    ->setCountQuery($count_query);
  $result = $query->execute();

  if ($result->rowCount() > 0) {
    drd_operation_build_form($form, 'server');
  }

  $destination = drupal_get_destination();

  $server = array();
  foreach ($result as $s) {
    $count = db_select('drd_domain', 'd')->fields('d', array('did'))->condition('d.sid', $s->sid)->countQuery()->execute()->FetchField();
    $extra = '<div class="drd-info element-hidden">&nbsp;</div>';
    $count_warning = db_select('drd_domain', 'd')->fields('d', array('did'))->condition('d.sid', $s->sid)->condition('d.status_w', 1)->countQuery()->execute()->FetchField();
    $count_error = db_select('drd_domain', 'd')->fields('d', array('did'))->condition('d.sid', $s->sid)->condition('d.status_e', 1)->countQuery()->execute()->FetchField();
    $warning = ($count_warning) ? drd_icon('warning') : '';
    $error   = ($count_error) ? drd_icon('error') : '';

    $server[$s->sid] = array(
      '#attributes' => array(
        'id' => 'drd-server-' . $s->sid,
        'class' => array('drd-data'),
      ),
      'name'   => array(
        'data' => l($s->name, 'admin/config/system/drd/server/' . $s->sid . '/edit', array('query' => $destination)) . $extra,
        'class' => array('name'),
      ),
      'url'    => l($s->url, drd_url($s), array('attributes' => array('target' => '_blank'))),
      'usessl' => ($s->usessl) ? t('Yes') : t('No'),
      'status' => array(
        'data' => (($s->status) ? t('Active') : t('Disabled')) . $warning . $error,
        'class' => array('pointer'),
      ),
      'drupal' => $s->drupalversion,
      'svn'    => ($s->usessl) ? t('Yes') : t('No'),
      'domains'=> l($count, 'admin/config/system/drd/dashboard/domains/' . $s->sid),
    );
  }

  $form['server'] = array(
    '#type' => 'tableselect',
    '#header' => $header,
    '#options' => $server,
    '#empty' => t('No server available.'),
  );
  $form['server_list_pager'] = array('#theme' => 'pager');

  drupal_add_js(array('drd' => array('urlAjax' => url('admin/drd/ajax/server/'))), 'setting');

  return $form;
}

/**
 * Builds the filter form for the server list.
 *
 * @return type
 */
function drd_server_filter_form() {
  return array();
}

/**
 * Builds the filter query for the server list.
 *
 * @param type $query
 */
function drd_server_build_filter_query(&$query) {

}
